@@ -62,7 +62,7 @@ class Scraper:
         """
         Returns a list of links
         """
-        return List(str).extend([a.get('href') for a in self._soup.find_all('a') if isinstance(a.get('href'), str)])
+        return List(str).extend([str(a.get('href')) for a in self._soup.find_all('a')])
 
     def __str__(self):
         return f"""
